package org.gcube.portlets.user.geoportaldataviewer.client.ui;

import org.gcube.portlets.user.geoportaldataviewer.client.gis.OpenLayerOSM;
import org.gcube.portlets.user.geoportaldataviewer.shared.GeoNaItemRef;
import org.gcube.portlets.user.geoportaldataviewer.shared.products.ConcessioneDV;
import org.gcube.portlets.user.geoportaldataviewer.shared.products.model.RecordDV;

import com.github.gwtbootstrap.client.ui.Button;
import com.github.gwtbootstrap.client.ui.NavLink;
import com.github.gwtbootstrap.client.ui.constants.IconType;
import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.event.shared.HandlerManager;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.HTMLPanel;
import com.google.gwt.user.client.ui.Widget;

public class GeonaDataViewMainPanel extends Composite {

	private static GeonaDataViewMainPanelUiBinder uiBinder = GWT.create(GeonaDataViewMainPanelUiBinder.class);

	interface GeonaDataViewMainPanelUiBinder extends UiBinder<Widget, GeonaDataViewMainPanel> {
	}

//	@UiField
//	Tab mapTabPanel;
	
	@UiField
	HTMLPanel mainContainerPanel;
	
	@UiField
	HTMLPanel mainToolBar;


	@UiField
	NavLink dataPointSelection;

	@UiField
	NavLink dataBoxSelection;
	
	@UiField
	Button removeQuery;
	
	@UiField
	DetailsPanel detailsPanel;

	private MapPanel mapPanel;

	private OpenLayerOSM map;

	private HandlerManager eventBus;

	public GeonaDataViewMainPanel(HandlerManager eventBus, int mapHeight) {
		initWidget(uiBinder.createAndBindUi(this));
		this.eventBus = eventBus;
		mapPanel = new MapPanel(mapHeight+"px");
		detailsPanel.setHeight(mapHeight+"px");
		mainContainerPanel.add(mapPanel);
		bindHandlers();
		dataPointSelection.setIcon(IconType.SCREENSHOT);
		dataBoxSelection.setIcon(IconType.BOOKMARK);
		
		removeQuery.setIcon(IconType.REMOVE);
	}

	public void setPanelsHeight(int height) {
		String toH = height + "px";
		mapPanel.setMapHeight(height);
		detailsPanel.setHeight(toH);
	}

	public MapPanel getMapPanel() {
		return mapPanel;
	}

	public void setMap(OpenLayerOSM map) {
		this.map = map;
	}

	public void bindHandlers() {

		dataPointSelection.addClickHandler(new ClickHandler() {

			@Override
			public void onClick(ClickEvent event) {
				map.removeQueryInteractions();
				GWT.log("dataPointSelection.isActive() " + dataPointSelection.isActive());
				if (!dataPointSelection.isActive()) {
					map.addPointVectorSource();
				}
				removeQuery.setVisible(true);
			}
		});

		dataBoxSelection.addClickHandler(new ClickHandler() {

			@Override
			public void onClick(ClickEvent event) {
				map.removeQueryInteractions();
				GWT.log("dataBoxSelection.isActive() " + dataBoxSelection.isActive());
				if (!dataBoxSelection.isActive()) {
					map.addExtentInteraction();
				}
				removeQuery.setVisible(true);
			}
		});
		
		removeQuery.addClickHandler(new ClickHandler() {
			
			@Override
			public void onClick(ClickEvent event) {
				map.removeQueryInteractions();
				removeQuery.setVisible(false);
			}
		});

	}

	public void showAsDetails(ConcessioneDV concessioneDV, GeoNaItemRef geonaItemRef) {
		detailsPanel.showDetailsFor(concessioneDV, geonaItemRef);
		
	}
	
	public void hidePanelDetails() {
		detailsPanel.hidePanelDetails();
		
	}
	
	public RecordDV getDisplyedRecord() {
		return detailsPanel.getDisplayedRecord();
	}

}
